Module extraction

Module extraction 

Functions

extract_deletions
Ask the LLM which existing relations should be invalidated given new data. Returns triples (source, relationship, destination) to soft-delete.
extract_entities
Extract entities from a conversation using the LLM.
extract_relations
Extract relations between entities from a conversation using the LLM.