Functions
- extract_
deletions - Ask the LLM which existing relations should be invalidated given new data.
Returns triples
(source, relationship, destination)to soft-delete. - extract_
entities - Extract entities from a conversation using the LLM.
- extract_
relations - Extract relations between entities from a conversation using the LLM.